@@ -55,14 +55,15 @@ def __dobjUrl__(dobj):
         dobj = str(dobj)
     except:
        raise Exception('dobj not a string') 
+       
+       
+    if 'meta.icos-cp' in dobj:
+        # we assume a full ICOS URI is provided, we only need to add <>
+        return '<' + dobj + '>'
     
-    if len(dobj.split('/')) > 1:
-        # we assume the full url / handle is provided as string
-        url = '<' + dobj + '>'        
-    else:
-        # we assume only the PID is provided
-        url = '<https://meta.icos-cp.eu/objects/'+ dobj + '>'
-        
+    # this case assumes either the PID only, or possibly the handle.net
+    pid = dobj.split('/')[-1]
+    url = '<https://meta.icos-cp.eu/objects/%s>' % pid
     return url        
 
 # --------------------------------------------------------------------
@@ -219,24 +220,54 @@ def atc_nrt_level_1(limit=0):
     return query
 # ---------------------------------------------------------------------------
 
-def collections(limit=0):
-    """ Return all known collections """
+def collections(id=None):
+    """
+    Return Collections
+    Parameters
+    ----------
+    id : STR, optional
+        The default is None, which returns all know collections.
+        You can provide a ICOS URI or DOI to filter for a specifict collection
 
+    Returns
+    -------
+    query : STR
+        A query, which can be run against the SPARQL endpoint.
+    """
+    
+    if not id:
+        coll = '' # create an empyt string insert into sparql query
+    else:
+        coll = ''.join(['FILTER(str(?collection) = "' + id+ '" || ?doi = "' + id + '") .'])
+       
     query = """
             prefix cpmeta: <http://meta.icos-cp.eu/ontologies/cpmeta/>
             prefix dcterms: <http://purl.org/dc/terms/>
             select * where{
-            ?coll a cpmeta:Collection .
-            OPTIONAL{?coll cpmeta:hasDoi ?doi}
-            ?coll dcterms:title ?title .
-            }
+            ?collection a cpmeta:Collection .
             %s
-            """ % __checklimit__(limit)
+            OPTIONAL{?collection cpmeta:hasDoi ?doi} .
+            ?collection dcterms:title ?title .
+            OPTIONAL{?collection dcterms:description ?description}
+            FILTER NOT EXISTS {[] cpmeta:isNextVersionOf ?collection}
+            }
+            order by ?title
+            """ % coll
 
     return query
 
 
 # -----------------------------------------------------------------------------
+def collection_items(id):
+    
+    """ Return all item for a collection """
+    
+    query = """    
+            select * where{ %s <http://purl.org/dc/terms/hasPart> ?dobj}
+
+            """ % __dobjUrl__(id)
+    return query
+# -----------------------------------------------------------------------------
 
 def stationData(uri, level='2'):
     """
